#[non_exhaustive]pub struct HoopedHandler { /* private fields */ }Expand description
Handler that wrap Handler to let it use middlewares.
Implementations
Sourceimpl HoopedHandler
impl HoopedHandler
Sourcepub fn hoops(&self) -> &Vec<Arc<dyn Handler>>
pub fn hoops(&self) -> &Vec<Arc<dyn Handler>>
Get a reference to the middlewares attached to this handler.
Sourcepub fn hoops_mut(&mut self) -> &mut Vec<Arc<dyn Handler>>
pub fn hoops_mut(&mut self) -> &mut Vec<Arc<dyn Handler>>
Get a mutable reference to the middlewares attached to this handler.